@@ -1,9 +1,9 @@
 /*
-** Copyright (C) 2003-2006 Teus Benschop.
+** Copyright (©) 2003-2009 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 **  
 ** This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
 **  
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 **  
 */
 
@@ -24,6 +24,8 @@
 
 #include "libraries.h"
 #include <gtk/gtk.h>
+#include "types.h"
+#include "ot-nt-parallels.h"
 
 
 void checks_output_references_comments
@@ -42,8 +44,11 @@ public:
   void word_inventory (const vector<ustring>& words, const vector<unsigned int>& count,
                        int total, int unique, int filteredtotal, int filteredunique,
                        int excludelimit);
-  void usfm_count (const vector<ustring>& usfms, const vector<unsigned int>& count);
+  void usfm_count (const vector<ustring>& usfms, const vector<unsigned int>& count, const ustring& stylesheet);
   void character_count (const vector<ustring>& chars, const vector<unsigned int>& count);
+  void references_inventory (const vector <ustring>& verses, const vector <ustring>& references);
+  void ot_quotations_in_nt (const vector <ustring> nt_refs, const vector <ustring> nt_texts, const vector <VectorUstring>& ot_refs, const vector <VectorUstring>& ot_texts, const gchar * mainheading);
+  void parallel_passages (const vector <OtNtParallelDataSection>& data, const gchar * mainheading);
 private:
   vector <ustring> html;
   void start (const ustring& title);
@@ -53,7 +58,7 @@ private:
   void close_table ();
   void open_table_column ();
   void close_table_column ();
-  void add_table_cell (const ustring& text, bool bold, bool right_aligned);
+  void add_table_cell (const ustring& text, bool bold, bool right_aligned, bool translate_entities = true);
   void finalize ();
   ustring search_whole_words (const ustring& text, const ustring& word);
 };
