@@ -1,9 +1,9 @@
 /*
-** Copyright (C) 2003-2006 Teus Benschop.
+** Copyright (©) 2003-2009 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 **  
 ** This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
 **  
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 **  
 */
 
@@ -46,6 +46,15 @@ protected:
   GtkWidget *hbox6;
   GtkWidget *image3;
   GtkWidget *label25;
+  
+  // Compressed file.  
+  GtkWidget *label_compressed;
+  GtkWidget *button_compressed;
+  GtkWidget *alignment9;
+  GtkWidget *hbox14;
+  GtkWidget *image13;
+  GtkWidget *label43;
+  
   GtkWidget *label_unicode;
   GtkWidget *image_unicode;
   GtkWidget *label_unicode_gui;
@@ -66,10 +75,6 @@ protected:
   GtkWidget *label28;
   GtkWidget *label_directory;
   GtkWidget *label_import;
-  GtkWidget *image_type;
-  GtkWidget *label_type_gui;
-  GtkWidget *label35;
-  GtkWidget *combobox_type;
   GtkWidget *image_assign_ok;
   GtkWidget *label_assign_ok;
   GtkWidget *label_assign_question;
@@ -81,8 +86,14 @@ protected:
   GtkWidget *label_assign_info;
   GtkWidget *expander1;
   GtkWidget *vbox2;
-  GtkWidget *checkbutton_link;
   GtkWidget *checkbutton_overwrite;
+  GtkWidget *hbox_book_names;
+  GtkWidget *checkbutton_book_names;
+  GtkWidget *button_book_names;
+  GtkWidget *alignment10;
+  GtkWidget *hbox16;
+  GtkWidget *image14;
+  GtkWidget *label44;
   GtkWidget *label42;
   GtkWidget *dialog_action_area1;
   GtkWidget *cancelbutton;
@@ -97,12 +108,13 @@ private:
   set <unsigned int> selected_books;
   vector <ustring> filenames_not_in_unicode;
   ustring encoding_convert_from;
+  bool assigning_done;
   ustring pick_newest_filename (const vector <ustring> &filenames);
   static void on_button_directory_clicked (GtkButton *button, gpointer user_data);
-  void on_button_directory ();
-  static void on_combobox_type_changed (GtkComboBox *combobox, gpointer user_data);
-  void on_type ();
-  ImportType get_type ();
+  void on_button_directory (ustring dir);
+  ImportType importtype;
+  static void on_button_compressed_clicked (GtkButton *button, gpointer user_data);
+  void on_button_compressed();
   static void on_button_assign_clicked (GtkButton *button, gpointer user_data);
   void on_button_assign ();
   static void on_button_books_clicked (GtkButton *button, gpointer user_data);
@@ -113,6 +125,12 @@ private:
   static void on_okbutton_clicked (GtkButton *button, gpointer user_data);
   void on_okbutton ();
   void set_gui ();
+  ustring uncompress_directory();
+  map <unsigned int, ustring> unusual_book_names;
+  static void on_checkbutton_book_names_toggled (GtkToggleButton *togglebutton, gpointer user_data);
+  void on_checkbutton_book_names();
+  static void on_button_book_names_clicked (GtkButton *button, gpointer user_data);
+  void on_button_book_names();
 };
 
 
