@@ -1,9 +1,9 @@
 /*
-** Copyright (C) 2003-2006 Teus Benschop.
+** Copyright (©) 2003-2009 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 **  
 ** This program is distributed in the hope that it will be useful,
@@ -13,10 +13,11 @@
 **  
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 **  
 */
 
+
 #ifndef INCLUDED_GWRAPPERS_H
 #define INCLUDED_GWRAPPERS_H
 
@@ -36,6 +37,43 @@ void gw_error (const ustring& error);
 ustring gw_path_get_basename (const ustring& filename);
 ustring gw_path_get_dirname (const ustring& filename);
 bool gw_find_program_in_path (const ustring& program);
+void gw_destroy_source (guint& event_id);
+void gw_mkdir_with_parents (const ustring& directory);
+
+
+class GwSpawn
+{
+public:
+  GwSpawn (const char * program);
+  ~GwSpawn ();
+  void workingdirectory (ustring directory);
+  void arg (ustring value);
+  void async ();
+  void devnull ();
+  void write (ustring text);
+  void read ();
+  void progress (ustring text, bool allow_cancel);
+  void describe ();
+  void run ();
+  bool cancelled;
+  bool result;
+  gint exitstatus;
+  GPid pid;
+  vector <ustring> standardout;
+  vector <ustring> standarderr;
+private:
+  const char * myprogram;
+  ustring myworkingdirectory;
+  bool myasync;
+  bool mydevnull;
+  ustring mywrite;
+  bool myread;
+  bool myprogress;
+  bool myallowcancel;
+  bool myhide;
+  ustring mytext;
+  vector <ustring> myarguments;
+};
 
 
 #endif
