@@ -1,9 +1,9 @@
 /*
-** Copyright (C) 2003-2006 Teus Benschop.
+** Copyright (©) 2003-2009 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 **  
 ** This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
 **  
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 **  
 */
 
@@ -24,6 +24,7 @@
 
 #include "libraries.h"
 #include <gtk/gtk.h>
+#include "types.h"
 
 
 class ImportBookRead
@@ -33,6 +34,7 @@ public:
   void usfm ();
   void bibleworks ();
   void mechonmamre ();
+  void onlinebible (map <ustring, unsigned int> bookmap);
   vector<ustring> lines;
   ustring bookname;
 private:
@@ -43,10 +45,14 @@ private:
 gchar * unicode_convert (gchar *data, const ustring& encoding);
 
 
+ustring import_type_human_readable (ImportType importtype);
 ustring bibleworks_file_get_bookname (const ustring& filename);
 vector<ustring> bibleworks_file_divide (const ustring& inputfile);
 bool mechon_mamre_copyright (const ustring& inputfile);
 vector<ustring> mechon_mamre_produce_master_files (const vector<ustring>& inputfiles);
+bool online_bible_file (const ustring& filename);
+bool online_bible_parse_reference (ustring line, unsigned int& book, unsigned int& chapter, unsigned int& verse, map <ustring, unsigned int>& bookmap);
+vector <ustring> online_bible_file_divide (const ustring& inputfile, map <ustring, unsigned int> bookmap);
 
 
 #endif
