@@ -1,9 +1,9 @@
 /*
-** Copyright (C) 2003-2006 Teus Benschop.
+** Copyright (©) 2003-2009 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 **  
 ** This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
 **  
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 **  
 */
 
@@ -29,10 +29,12 @@
 
 void projects_initial_check (bool gui);
 vector<ustring> projects_get_all ();
-ustring project_filename (const ustring& project);
-ustring project_book_filename (const ustring& project, unsigned int book, bool check_exists = true);
+ustring project_data_directory_project (const ustring& project);
+ustring project_data_directory_book (const ustring& project, unsigned int book);
+ustring project_data_directory_chapter (const ustring& project, unsigned int book, unsigned int chapter);
+ustring project_data_filename_chapter (const ustring& project, unsigned int book, unsigned int chapter, bool checkexists);
 bool project_exists (const ustring& project);
-void project_create (const ustring& project);
+void project_create_restore (const ustring& project, const ustring& restore_from);
 void project_delete (const ustring& project);
 void project_copy (const ustring& project, const ustring& newproject);
 void project_move (const ustring& project, const ustring& newproject);
@@ -41,30 +43,15 @@ void project_remove_book (const ustring& project, unsigned int book);
 void project_store_chapter (const ustring& project, unsigned int book, CategorizeChapterVerse& ccv);
 void project_remove_chapter (const ustring& project, unsigned int book, unsigned int chapter);
 void project_store_verse (const ustring& project, unsigned int book, unsigned int chapter, const ustring& verse, const ustring& data);
-void project_update_book (const ustring& project, unsigned int book, unsigned int timestamp);
 ustring project_retrieve_verse (const ustring& project, unsigned int book, unsigned int chapter, const ustring& verse);
 vector<ustring> project_retrieve_chapter (const ustring& project, unsigned int book, unsigned int chapter);
 vector<ustring> project_retrieve_book (const ustring& project, unsigned int book);
-unsigned int project_retrieve_timestamp (const ustring& project);
-void project_link_book (const ustring& project, unsigned int book, const ustring& file);
-
-class ProjectLinksGet
-{
-public:
-  ProjectLinksGet (const ustring& project);
-  vector<unsigned int> books;
-  vector<bool> updateds;
-  vector<ustring> filenames;
-  vector<unsigned int> filetimes;
-  vector<unsigned int> filesizes;
-private:
-};
-
 vector<unsigned int> project_get_books (const ustring& project);
 vector<unsigned int> project_get_chapters (const ustring& project, unsigned int book);
 vector<ustring> project_get_verses (const ustring& project, unsigned int book, unsigned int chapter);
 bool project_book_exists (const ustring& project, unsigned int book);
-void project_vacuum (const ustring& project, unsigned int starttime);
+
+bool project_select (ustring& newproject);
 
 
 #endif
