@@ -1,9 +1,9 @@
 /*
-** Copyright (C) 2003-2006 Teus Benschop.
+** Copyright (©) 2003-2009 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 **  
 ** This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
 **  
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 **  
 */
 
@@ -31,12 +31,9 @@ bool program_is_running (const ustring & commandline);
 int programs_running_count (const ustring & commandline);
 bool program_is_running_basic (const ustring & program);
 int programs_running_count_basic (const ustring & program);
-int run_shell_progress (const ustring& commandline, const ustring& programname, 
-                        bool gui, const ustring& message, 
-                        bool output_to_logfile, int max_logfile_size);
 ustring shell_quote_space (const ustring& filename);
-bool copy_file (const ustring& from, const ustring& to);
 ustring shell_clean_filename (const ustring& filename);
+void shell_pipe_file_append (const ustring& inputfile, const ustring& outputfile);
 
 
 #endif
