@@ -1,9 +1,9 @@
 /*
-** Copyright (C) 2003-2006 Teus Benschop.
+** Copyright (©) 2003-2009 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 **  
 ** This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
 **  
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 **  
 */
 
@@ -25,6 +25,7 @@
 typedef vector <ustring> VectorUstring;
 
 enum NoteType {indtFootnote, indtEndnote, indtCrossreference};
+enum NumberingType {ntAutomatic, ntNone, ntCharacter};
 
 enum SearchResultsType {sstLoad, sstAdd, sstSubtract, sstShare};
 
@@ -34,11 +35,23 @@ enum CheckSortType {cstSort0, cstSort1, cstSort2, cstSort3};
 
 enum AreaType {atRaw, atAll, atSelection};
 
-enum ImportType {itUsfm, itBibleWorks, itMechonMamre};
+enum ImportType {itUsfm, itBibleWorks, itMechonMamre, itOnlineBible};
 
 enum WineType {wtWine, wtCxoffice, wtUnknown};
 
-enum OriginReferencesActionType {oratNothing, oratRemove, oratAdd};
+enum OriginReferencesActionType {oratNothing, oratRemoveReferences, oratAddReference, oratTextLabels };
+
+enum StylesheetType {stBasic, stBasicParagraph, stBasicParagraphWordNote, 
+                     stSilBestPractice, stFull};
+
+enum NotesSelectionReferenceType {nsrtCurrentVerse, nsrtCurrentChapter, nsrtCurrentBook, nsrtAny};
+enum NotesSelectionEditedType {nsetToday, nsetDateRange, nsetAny};
+                              
+enum ResourceConversionType {
+  rctChapterStartsAtPatternVerseOneStartsAtChapterVerseStartsAtPattern,
+  rctEnd
+};
+
 
 
 #endif
